Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1258)

Unified Diff: build/vs_toolchain.py

Issue 951673002: Revert "Pull chromium at 2c3ffb2355a27c32f45e508ef861416b820c823b" (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/toolchain/win/setup_toolchain.py ('k') | build/win/install-build-deps.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/vs_toolchain.py
diff --git a/build/vs_toolchain.py b/build/vs_toolchain.py
index 5b175eb13169af7dc7f9a51619052ce92fabf88c..6f49e7c2e8e01692842537b0471b3583ae2a8c66 100644
--- a/build/vs_toolchain.py
+++ b/build/vs_toolchain.py
@@ -129,11 +129,11 @@ def CopyVsRuntimeDlls(output_dir, runtime_dirs):
source_x64)
-def CopyDlls(target_dir, configuration, target_cpu):
+def CopyDlls(target_dir, configuration, cpu_arch):
"""Copy the VS runtime DLLs into the requested directory as needed.
configuration is one of 'Debug' or 'Release'.
target_cpu is one of 'x86' or 'x64'.
The debug configuration gets both the debug and release DLLs; the
release config only the latter.
@@ -143,7 +143,7 @@ def CopyDlls(target_dir, configuration, target_cpu):
return
x64_runtime, x86_runtime = vs2013_runtime_dll_dirs
- runtime_dir = x64_runtime if target_cpu == 'x64' else x86_runtime
+ runtime_dir = x64_runtime if cpu_arch == 'x64' else x86_runtime
_CopyRuntime(target_dir, runtime_dir, 'msvc%s120.dll')
if configuration == 'Debug':
_CopyRuntime(target_dir, runtime_dir, 'msvc%s120d.dll')
@@ -129,11 +129,11 @@ def CopyVsRuntimeDlls(output_dir, runtime_dirs):
"""Copy the VS runtime DLLs into the requested directory as needed.
configuration is one of 'Debug' or 'Release'.
- target_cpu is one of 'x86' or 'x64'.
+ cpu_arch is one of 'x86' or 'x64'.
The debug configuration gets both the debug and release DLLs; the
release config only the latter.
« no previous file with comments | « build/toolchain/win/setup_toolchain.py ('k') | build/win/install-build-deps.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698